@@ -57,11 +57,11 @@
 #include <urlutil.h>
 
 typedef KDevGenericFactory<TrollProjectPart> TrollProjectFactory;
-static const KDevPluginInfo data("kdevtrollproject");
-K_EXPORT_COMPONENT_FACTORY( libkdevtrollproject, TrollProjectFactory( data ) )
+static const KDevPluginInfo pluginData("kdevtrollproject");
+K_EXPORT_COMPONENT_FACTORY( libkdevtrollproject, TrollProjectFactory( pluginData ) )
 
 TrollProjectPart::TrollProjectPart(TQObject *parent, const char *name, const TQStringList& args )
-    : KDevBuildTool(&data, parent, name ? name : "TrollProjectPart")
+    : KDevBuildTool(&pluginData, parent, name ? name : "TrollProjectPart")
 {
     setInstance(TrollProjectFactory::instance());
 
@@ -925,7 +925,3 @@ void TrollProjectPart::slotBuild()
 }
 
 #include "trollprojectpart.moc"
-
-//kate: space-indent on; indent-width 4; tab-width 4; replace-tabs on
-
-
