@@ -18,6 +18,14 @@
 
 **********************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#ifndef TQTDOCDIR
+#define TQTDOCDIR "/usr/share/tqt3/doc/html"
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <sys/stat.h>
@@ -118,7 +126,7 @@ static TQString textNoAccel(const TQString& text)
 MainWindow::MainWindow(bool asClient)
   : KParts::DockMainWindow(0, "mainwindow", WType_TopLevel | WDestructiveClose | WGroupLeader),
       grd(10, 10), sGrid(true), snGrid(true), restoreConfig(true), splashScreen(true),
-      docPath("$TQTDIR/doc/html"), client(asClient),  databaseAutoEdit(false), previewing(false)
+      docPath(TQTDOCDIR), client(asClient),  databaseAutoEdit(false), previewing(false)
 {
   m_partManager = new KParts::PartManager(this);
   //connect(m_partManager, TQT_SIGNAL(activePartChanged(KParts::Part * )),          this, TQT_SLOT(slotActivePartChanged(KParts::Part * )));
