@@ -324,17 +324,17 @@ bool TQGArray::fill( const char *d, int len, uint sz )
     if ( sz == 1 )				// 8 bit elements
 	memset( data(), *d, len );
     else if ( sz == 4 ) {			// 32 bit elements
-	register TQ_INT32 *x = (TQ_INT32*)data();
+	TQ_INT32 *x = (TQ_INT32*)data();
 	TQ_INT32 v = *((TQ_INT32*)d);
 	while ( len-- )
 	    *x++ = v;
     } else if ( sz == 2 ) {			// 16 bit elements
-	register TQ_INT16 *x = (TQ_INT16*)data();
+	TQ_INT16 *x = (TQ_INT16*)data();
 	TQ_INT16 v = *((TQ_INT16*)d);
 	while ( len-- )
 	    *x++ = v;
     } else {					// any other size elements
-	register char *x = data();
+	char *x = data();
 	while ( len-- ) {			// more complicated
 	    memcpy( x, d, sz );
 	    x += sz;
@@ -400,7 +400,7 @@ TQGArray &TQGArray::duplicate( const TQGArray &a )
     if ( a.shd == shd ) {			// a.duplicate(a) !
 	if ( shd->count > 1 ) {
 	    shd->count--;
-	    register array_data *n = newData();
+	    array_data *n = newData();
 	    TQ_CHECK_PTR( n );
 	    if ( (n->len=shd->len) ) {
 		n->data = NEW(char,n->len);
@@ -605,11 +605,11 @@ int TQGArray::find( const char *d, uint index, uint sz ) const
 #endif
 	return -1;
     }
-    register uint i;
+    uint i;
     uint ii;
     switch ( sz ) {
 	case 1: {				// 8 bit elements
-	    register char *x = data() + index;
+	    char *x = data() + index;
 	    char v = *d;
 	    for ( i=index; i<shd->len; i++ ) {
 		if ( *x++ == v )
@@ -619,7 +619,7 @@ int TQGArray::find( const char *d, uint index, uint sz ) const
 	    }
 	    break;
 	case 2: {				// 16 bit elements
-	    register TQ_INT16 *x = (TQ_INT16*)(data() + index);
+	    TQ_INT16 *x = (TQ_INT16*)(data() + index);
 	    TQ_INT16 v = *((TQ_INT16*)d);
 	    for ( i=index; i<shd->len; i+=2 ) {
 		if ( *x++ == v )
@@ -629,7 +629,7 @@ int TQGArray::find( const char *d, uint index, uint sz ) const
 	    }
 	    break;
 	case 4: {				// 32 bit elements
-	    register TQ_INT32 *x = (TQ_INT32*)(data() + index);
+	    TQ_INT32 *x = (TQ_INT32*)(data() + index);
 	    TQ_INT32 v = *((TQ_INT32*)d);
 	    for ( i=index; i<shd->len; i+=4 ) {
 		if ( *x++ == v )
@@ -659,11 +659,11 @@ int TQGArray::find( const char *d, uint index, uint sz ) const
 
 int TQGArray::contains( const char *d, uint sz ) const
 {
-    register uint i = shd->len;
+    uint i = shd->len;
     int count = 0;
     switch ( sz ) {
 	case 1: {				// 8 bit elements
-	    register char *x = data();
+	    char *x = data();
 	    char v = *d;
 	    while ( i-- ) {
 		if ( *x++ == v )
@@ -672,7 +672,7 @@ int TQGArray::contains( const char *d, uint sz ) const
 	    }
 	    break;
 	case 2: {				// 16 bit elements
-	    register TQ_INT16 *x = (TQ_INT16*)data();
+	    TQ_INT16 *x = (TQ_INT16*)data();
 	    TQ_INT16 v = *((TQ_INT16*)d);
 	    i /= 2;
 	    while ( i-- ) {
@@ -682,7 +682,7 @@ int TQGArray::contains( const char *d, uint sz ) const
 	    }
 	    break;
 	case 4: {				// 32 bit elements
-	    register TQ_INT32 *x = (TQ_INT32*)data();
+	    TQ_INT32 *x = (TQ_INT32*)data();
 	    TQ_INT32 v = *((TQ_INT32*)d);
 	    i /= 4;
 	    while ( i-- ) {
